@@ -751,13 +751,16 @@ def CalculatingICITYMetric(SortedBLASTHitsFolder=os.path.join("./" + "RM_A"+"_OU
 
 
 # step 14
-def SortRelevance(DefenseSystem_Name="RM_A", DefenseSystem_FilePath="./"):
+def SortRelevance(DefenseSystem_Name="RM_A", DefenseSystem_FilePath="./", PathToDatabase="Database/ArchaeaProt"):
+    # Relevance.tsv
     CLUSTER_NAME = 0
     NUMBER_IN_VICINTY = 1
     NUMBER_IN_ENTIRE = 2
     DISTANCE_TO_SEED = 3
     DS3P = 4
 
+
+
     # 阈值暂定，需要使用统计得到一个有说服力的数值
     DS3P_threshold = 0.0
 
@@ -770,18 +773,17 @@ def SortRelevance(DefenseSystem_Name="RM_A", DefenseSystem_FilePath="./"):
 
     class NotDefenseSystem(Exception): pass
 
-    # 修改文件位置
 
     SeedAccession_Filename = DefenseSystem_FilePath+ DefenseSystem_Name + '_OUTPUT/Seeds_' + DefenseSystem_Name + '.tsv'
     CLUSTERS_Filepath = DefenseSystem_FilePath + DefenseSystem_Name + '_OUTPUT/CLUSTERS_' + DefenseSystem_Name 
     CLUSTERHitsSorted_path = DefenseSystem_FilePath + DefenseSystem_Name + '_OUTPUT/CLUSTERS_' + DefenseSystem_Name + '/Sorted/'
     Vicinity_Filename=(os.path.split(DefenseSystem_FilePath+ DefenseSystem_Name + '_OUTPUT/Vicinity_'+ DefenseSystem_Name + '.faa')[1])
     Relevance_Filenpath = DefenseSystem_FilePath+DefenseSystem_Name + '_OUTPUT/Relevance_' + DefenseSystem_Name + '.tsv'
-    #Relevance_Filename = 'Relevance_ABI_A.tsv'
-    Relevance_CategoryName = 'Relevance_Sorted_'+ DefenseSystem_Name + '_Category.csv'
+    Relevance_CategoryName = DefenseSystem_FilePath+DefenseSystem_Name + '_OUTPUT/Relevance_Sorted_'+ DefenseSystem_Name + '_Category.csv'
     CLUSTERS_Filenpath = DefenseSystem_FilePath + DefenseSystem_Name + '_OUTPUT/CLUSTERS_' + DefenseSystem_Name 
 
 
+
     def makecategoryfile(DefenseSystem_Name, DefenseSystem_Function):
         tmplist = [DefenseSystem_Function_1,DefenseSystem_Function_2,DefenseSystem_Function_3,DefenseSystem_Function_4,DefenseSystem_Function_5]
         tmpname = ''
@@ -811,7 +813,6 @@ def SortRelevance(DefenseSystem_Name="RM_A", DefenseSystem_FilePath="./"):
         os.mkdir(Dir)
 
 
-
     if 'ABI' in DefenseSystem_Name:
             makecategoryfile(DefenseSystem_Name, DefenseSystem_Function_1)
     elif 'RM' in DefenseSystem_Name:
@@ -826,7 +827,6 @@ def SortRelevance(DefenseSystem_Name="RM_A", DefenseSystem_FilePath="./"):
             raise NotDefenseSystem("No related defense system is included")
 
 
-
     # 配合使用ACCESSION.sh 得到分类文件,不同抗性系统需要修改文件路径
     Accession_All_FileName = 'ACCESSION_A/ACCESSION_' + DefenseSystem_Name + '.txt'
     Accession_Category_Target_FileName = 'ACCESSION_A/ACCESSION_ONLY_'+ DefenseSystem_Name + '.txt'
@@ -835,6 +835,8 @@ def SortRelevance(DefenseSystem_Name="RM_A", DefenseSystem_FilePath="./"):
     ACCESSION_Other_DefenseGene_FileName = 'ACCESSION_A/ACCESSION_Other_DefenseGene_'+ DefenseSystem_Name + '.txt'
 
 
+
+
     with open(Relevance_Filenpath,'r') as F:
         Relevance = dict()
         for Line in F:
@@ -842,6 +844,7 @@ def SortRelevance(DefenseSystem_Name="RM_A", DefenseSystem_FilePath="./"):
             Relevance[LineValue[CLUSTER_NAME]] = [LineValue[CLUSTER_NAME], LineValue[NUMBER_IN_VICINTY], LineValue[NUMBER_IN_ENTIRE], LineValue[DISTANCE_TO_SEED], LineValue[DS3P]]
 
 
+
     Relevance_Sorted_Target = dict()
     for r in Relevance:
         if int(Relevance[r][NUMBER_IN_ENTIRE]) >= 1:
@@ -861,6 +864,9 @@ def SortRelevance(DefenseSystem_Name="RM_A", DefenseSystem_FilePath="./"):
         
         Relevance_Sorted_Target[n] = [Relevance_Sorted_Target[n], ProteinAccession]
 
+
+
+
     # 构建字典，引入分类符
     # 与输入数据一致的防御基因--1
     # 其他防御基因--2
@@ -892,6 +898,7 @@ def SortRelevance(DefenseSystem_Name="RM_A", DefenseSystem_FilePath="./"):
             Accession_Category_Hypothetical[LineValue[0]] = [LineValue[1], LineValue[2]]
 
 
+
     Relevance_Sorted_Target_Category = dict()
     for id in Relevance_Sorted_Target:
         # 每个Cluster 里多个 Accession 的功能可能不同，若不同，选取顺序如下: 1>2>3>4
@@ -923,6 +930,9 @@ def SortRelevance(DefenseSystem_Name="RM_A", DefenseSystem_FilePath="./"):
             Relevance_Sorted_Target_Category[id] = [Relevance_Sorted_Target[id][0], Accession_Category_Hypothetical[Cluster_Category_Name][1]]
 
 
+
+
+
     # 计算物种保守性（属-种分开算）
     def CalConservation(Accession_Taxonomy):
             count = 0
@@ -982,6 +992,7 @@ def SortRelevance(DefenseSystem_Name="RM_A", DefenseSystem_FilePath="./"):
             Relevance_Sorted_Target_Taxonomy[id] = [CalConservation(flipped_genus),CalConservation(flipped_species)]
 
 
+
     with open(Relevance_CategoryName,'w') as f:
         for i in Relevance_Sorted_Target_Category:
             for element in Relevance_Sorted_Target_Category[i][0]:
@@ -995,7 +1006,6 @@ def SortRelevance(DefenseSystem_Name="RM_A", DefenseSystem_FilePath="./"):
             f.write("\n")
 
 
-    #import seaborn as sns
 
     def visualize(pred_y, test_y):
         '''
@@ -1082,16 +1092,16 @@ def SortRelevance(DefenseSystem_Name="RM_A", DefenseSystem_FilePath="./"):
         reduce_known_pos = reduce_known_pos.reset_index(drop=True)
         reduce_known_pos.to_csv(outname,index= False)
         
-
         
-    filename = Relevance_CategoryName
-    outname = f"output_{filename}"
-    binary_cls_analysis(filename, outname)
+    if __name__ == '__main__':
+        filename = Relevance_CategoryName
+        outname = DefenseSystem_FilePath+DefenseSystem_Name + '_OUTPUT/output_Relevance_Sorted_'+ DefenseSystem_Name + '_Category.csv'
+        binary_cls_analysis(filename, outname)
 
 
 
     NewGene_ClusterIDs = pd.read_csv(outname)
-    NewGeneFile = 'NewGene_' + DefenseSystem_Name
+    NewGeneFile = DefenseSystem_FilePath + DefenseSystem_Name + '_OUTPUT/NewGene_' + DefenseSystem_Name
 
 
     if not os.path.exists(NewGeneFile):
@@ -1105,8 +1115,9 @@ def SortRelevance(DefenseSystem_Name="RM_A", DefenseSystem_FilePath="./"):
                 f.write(Relevance_Sorted_Target['CLUSTER_' + n][1][i])
                 f.write('\n')
 
-        subprocess.call('blastdbcmd -db Database/ProteinDB -entry_batch '+ NewGeneList +
-        ' -long_seqids > '+ NewGeneFile + '/' + DefenseSystem_Name + '_' +'CLUSTER_'+ n +'.faa',shell= True)
+        subprocess.call('blastdbcmd -db ' + PathToDatabase + ' -entry_batch ' + NewGeneList +
+                        ' -long_seqids > ' + NewGeneFile + '/' + DefenseSystem_Name + '_' + 'CLUSTER_' + n + '.faa',
+                        shell=True)
 
 
 
@@ -1182,4 +1193,4 @@ def LoupeRunner(DefenseSystem_Name,
                             BASE_DIR=BASE_DIR)
 
     print("Step 14: Sorting Relevance")
-    SortRelevance(DefenseSystem_Name, DefenseSystem_FilePath)
+    SortRelevance(DefenseSystem_Name, DefenseSystem_FilePath, PathToDatabase)
